# Steps to link grid5000
 Guid: https://www.grid5000.fr/w/SSH
 Manage account, add ssh, storage at https://api.grid5000.fr/stable/users/

```bash
    ssh access.grid5000.fr -l jiliu
    ssh lille
```
Check all possible known hosts `cat .ssh/known_hosts`.
Password: L9oo_0_7

